@@ -1,7 +1,7 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2016-08-03'; # DATE
-our $VERSION = '0.86'; # VERSION
+our $DATE = '2016-10-28'; # DATE
+our $VERSION = '0.87'; # VERSION
 
 use 5.010001;
 use strict;
@@ -294,7 +294,6 @@ argument's schema using `complete_from_schema`.
 Completion routine will get `%args`, with the following keys:
 
 * `word` (str, the word to be completed)
-* `ci` (bool, whether string matching should be case-insensitive)
 * `arg` (str, the argument name which value is currently being completed)
 * `index (int, only for the `complete_arg_elem` function, the index in the
    argument array that is currently being completed, starts from 0)
@@ -304,9 +303,9 @@ as well as extra keys from `extras` (but these won't overwrite the above
 standard keys).
 
 Completion routine should return a completion answer structure (described in
-`Complete`) which is either a hash or an array. The simplest form of answer is
-just to return an array of strings. Completion routine can also return undef to
-express declination.
+<pm:Complete>) which is either a hash or an array. The simplest form of answer
+is just to return an array of strings. Completion routine can also return undef
+to express declination.
 
 _
     args => {
@@ -335,8 +334,8 @@ _
             description => <<'_',
 
 The keys from this `extras` hash will be merged into the final `%args` passed to
-completion routines. Note that standard keys like `word`, `cword`, `ci`, and so
-on as described in the function description will not be overwritten by this.
+completion routines. Note that standard keys like `word`, `cword`, and so on as
+described in the function description will not be overwritten by this.
 
 _
         },
@@ -649,9 +648,9 @@ $SPEC{complete_cli_arg} = {
     summary => 'Complete command-line argument using Rinci function metadata',
     description => <<'_',
 
-This routine uses `Perinci::Sub::GetArgs::Argv` to generate `Getopt::Long`
+This routine uses <pm:Perinci::Sub::GetArgs::Argv> to generate <pm:Getopt::Long>
 specification from arguments list in Rinci function metadata and common options.
-Then, it will use `Complete::Getopt::Long` to complete option names, option
+Then, it will use <pm:Complete::Getopt::Long> to complete option names, option
 values, as well as arguments.
 
 _
@@ -676,8 +675,8 @@ _
             description => <<'_',
 
 If supplied, instead of the default completion routine, this code will be called
-instead. Will receive all arguments that `Complete::Getopt::Long` will pass, and
-additionally:
+instead. Will receive all arguments that <pm:Complete::Getopt::Long> will pass,
+and additionally:
 
 * `arg` (str, the name of function argument)
 * `args` (hash, the function arguments formed so far)
@@ -724,8 +723,8 @@ _
             description => <<'_',
 
 The keys from this `extras` hash will be merged into the final `%args` passed to
-completion routines. Note that standard keys like `word`, `cword`, `ci`, and so
-on as described in the function description will not be overwritten by this.
+completion routines. Note that standard keys like `word`, `cword`, and so on as
+described in the function description will not be overwritten by this.
 
 _
         },
@@ -734,10 +733,10 @@ _
             default => 0,
             description => <<'_',
 
-This is a (temporary?) workaround for Perinci::CmdLine. In an application with
-subcommands (e.g. `cmd --verbose subcmd arg0 arg1 ...`), then `words` will still
-contain the subcommand name. Positional function arguments then start at 1 not
-0. This option allows offsetting function arguments.
+This is a (temporary?) workaround for <pm:Perinci::CmdLine>. In an application
+with subcommands (e.g. `cmd --verbose subcmd arg0 arg1 ...`), then `words` will
+still contain the subcommand name. Positional function arguments then start at 1
+not 0. This option allows offsetting function arguments.
 
 _
         },
@@ -748,7 +747,7 @@ _
         schema => 'hash*',
         description => <<'_',
 
-You can use `format_completion` function in `Complete::Bash` module to format
+You can use `format_completion` function in <pm:Complete::Bash> module to format
 the result of this function for bash.
 
 _
@@ -815,6 +814,8 @@ sub complete_cli_arg {
             riap_client     => $args{riap_client},
         );
 
+        $extras->{parsed_opts} = $cargs{parsed_opts};
+
         if (my $sm = $specmeta->{$ospec}) {
             $cargs{type} = 'optval';
             if ($sm->{arg}) {
@@ -989,7 +990,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.86 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2016-08-03.
+This document describes version 0.87 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2016-10-28.
 
 =head1 SYNOPSIS
 
@@ -1016,8 +1017,6 @@ Completion routine will get C<%args>, with the following keys:
 
 =item * C<word> (str, the word to be completed)
 
-=item * C<ci> (bool, whether string matching should be case-insensitive)
-
 =item * C<arg> (str, the argument name which value is currently being completed)
 
 =item * C<index (int, only for the>complete_arg_elem` function, the index in the
@@ -1031,9 +1030,9 @@ as well as extra keys from C<extras> (but these won't overwrite the above
 standard keys).
 
 Completion routine should return a completion answer structure (described in
-C<Complete>) which is either a hash or an array. The simplest form of answer is
-just to return an array of strings. Completion routine can also return undef to
-express declination.
+L<Complete>) which is either a hash or an array. The simplest form of answer
+is just to return an array of strings. Completion routine can also return undef
+to express declination.
 
 This function is not exported by default, but exportable.
 
@@ -1054,8 +1053,8 @@ Collected arguments so far, will be passed to completion routines.
 Add extra arguments to completion routine.
 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
-completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
-on as described in the function description will not be overwritten by this.
+completion routines. Note that standard keys like C<word>, C<cword>, and so on as
+described in the function description will not be overwritten by this.
 
 =item * B<index> => I<int>
 
@@ -1115,8 +1114,6 @@ Completion routine will get C<%args>, with the following keys:
 
 =item * C<word> (str, the word to be completed)
 
-=item * C<ci> (bool, whether string matching should be case-insensitive)
-
 =item * C<arg> (str, the argument name which value is currently being completed)
 
 =item * C<index (int, only for the>complete_arg_elem` function, the index in the
@@ -1130,9 +1127,9 @@ as well as extra keys from C<extras> (but these won't overwrite the above
 standard keys).
 
 Completion routine should return a completion answer structure (described in
-C<Complete>) which is either a hash or an array. The simplest form of answer is
-just to return an array of strings. Completion routine can also return undef to
-express declination.
+L<Complete>) which is either a hash or an array. The simplest form of answer
+is just to return an array of strings. Completion routine can also return undef
+to express declination.
 
 This function is not exported by default, but exportable.
 
@@ -1153,8 +1150,8 @@ Collected arguments so far, will be passed to completion routines.
 Add extra arguments to completion routine.
 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
-completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
-on as described in the function description will not be overwritten by this.
+completion routines. Note that standard keys like C<word>, C<cword>, and so on as
+described in the function description will not be overwritten by this.
 
 =item * B<meta>* => I<hash>
 
@@ -1199,9 +1196,9 @@ Return value:  (array)
 
 Complete command-line argument using Rinci function metadata.
 
-This routine uses C<Perinci::Sub::GetArgs::Argv> to generate C<Getopt::Long>
+This routine uses L<Perinci::Sub::GetArgs::Argv> to generate L<Getopt::Long>
 specification from arguments list in Rinci function metadata and common options.
-Then, it will use C<Complete::Getopt::Long> to complete option names, option
+Then, it will use L<Complete::Getopt::Long> to complete option names, option
 values, as well as arguments.
 
 This function is not exported by default, but exportable.
@@ -1236,8 +1233,8 @@ C<get_args_from_argv()>. Example:
 Supply custom completion routine.
 
 If supplied, instead of the default completion routine, this code will be called
-instead. Will receive all arguments that C<Complete::Getopt::Long> will pass, and
-additionally:
+instead. Will receive all arguments that L<Complete::Getopt::Long> will pass,
+and additionally:
 
 =over
 
@@ -1258,15 +1255,15 @@ On which argument cursor is located (zero-based).
 Add extra arguments to completion routine.
 
 The keys from this C<extras> hash will be merged into the final C<%args> passed to
-completion routines. Note that standard keys like C<word>, C<cword>, C<ci>, and so
-on as described in the function description will not be overwritten by this.
+completion routines. Note that standard keys like C<word>, C<cword>, and so on as
+described in the function description will not be overwritten by this.
 
 =item * B<func_arg_starts_at> => I<int> (default: 0)
 
-This is a (temporary?) workaround for Perinci::CmdLine. In an application with
-subcommands (e.g. C<cmd --verbose subcmd arg0 arg1 ...>), then C<words> will still
-contain the subcommand name. Positional function arguments then start at 1 not
-0. This option allows offsetting function arguments.
+This is a (temporary?) workaround for L<Perinci::CmdLine>. In an application
+with subcommands (e.g. C<cmd --verbose subcmd arg0 arg1 ...>), then C<words> will
+still contain the subcommand name. Positional function arguments then start at 1
+not 0. This option allows offsetting function arguments.
 
 =item * B<meta>* => I<hash>
 
@@ -1315,7 +1312,7 @@ Command-line arguments.
 Return value:  (hash)
 
 
-You can use C<format_completion> function in C<Complete::Bash> module to format
+You can use C<format_completion> function in L<Complete::Bash> module to format
 the result of this function for bash.
 
 
